@@ -1,4 +1,4 @@
-/* $Id: extproc_perl.h,v 1.13 2004/02/14 19:45:44 jeff Exp $ */
+/* $Id: extproc_perl.h,v 1.17 2004/04/11 21:06:39 jeff Exp $ */
 
 #ifndef EXTPROC_PERL_H
 #define EXTPROC_PERL_H
@@ -10,6 +10,9 @@
 #define EP_SUBTYPE_FUNCTION	0
 #define EP_SUBTYPE_PROCEDURE	1
 
+#define EP_DDL_FORMAT_STANDARD	0
+#define EP_DDL_FORMAT_PACKAGE	1
+
 #define EP_DEBUG(c, msg) if (c->debug) { ep_debug(c, "%s", msg); }
 #define EP_DEBUGF(c, fmt, ...) if (c->debug) { ep_debug(c, fmt, __VA_ARGS__); }
 
@@ -42,19 +45,19 @@ struct ep_context {
 	char debug_dir[MAXPATHLEN];
 	char inc_path[4096];
 	char trusted_dir[MAXPATHLEN];
+	int ddl_format;
 	int use_namespace;
 	int tainting;
 	int package_subs;
-	int max_code_size;
-	int max_sub_args;
+	unsigned int max_code_size;
+	unsigned int max_sub_args;
 };
 typedef struct ep_context EP_CONTEXT;
 
 struct ep_code {
 	char label[255];
+	char plsql_spec[255];
 	char language[255];
-	char last_user[255];
-	char last_date[7];
 	char *code;
 	int code_len;
 };
@@ -63,6 +66,7 @@ typedef struct ep_code EP_CODE;
 void ora_exception(EP_CONTEXT *, char *);
 int fetch_code(EP_CONTEXT *, EP_CODE *, char *);
 int get_sessionid(EP_CONTEXT *, int *);
+int get_dbname(EP_CONTEXT *, char *);
 PerlInterpreter *pl_startup(EP_CONTEXT *);
 void _ep_init(EP_CONTEXT *, OCIExtProcContext *);
 char *parse_code(EP_CONTEXT *, EP_CODE *, char*);
